Class: Vangrail::Providers::Gateway::Spec

Inherits:
Struct
  • Object
show all
Defined in:
lib/vangrail/providers/gateway.rb

Overview

key_env, file_env, and pass_env name the environment variables that override each source. They are named rather than derived: a deployment that already documents WILLMA_PASS_ENTRY should not have to rename it to match a convention this gem invented.

Instance Attribute Summary collapse

Instance Attribute Details

#base_urlObject

Returns the value of attribute base_url

Returns:

  • (Object)

    the current value of base_url



43
44
45
# File 'lib/vangrail/providers/gateway.rb', line 43

def base_url
  @base_url
end

#file_envObject

Returns the value of attribute file_env

Returns:

  • (Object)

    the current value of file_env



43
44
45
# File 'lib/vangrail/providers/gateway.rb', line 43

def file_env
  @file_env
end

#guard_presetObject

Returns the value of attribute guard_preset

Returns:

  • (Object)

    the current value of guard_preset



43
44
45
# File 'lib/vangrail/providers/gateway.rb', line 43

def guard_preset
  @guard_preset
end

#key_envObject

Returns the value of attribute key_env

Returns:

  • (Object)

    the current value of key_env



43
44
45
# File 'lib/vangrail/providers/gateway.rb', line 43

def key_env
  @key_env
end

#key_fileObject

Returns the value of attribute key_file

Returns:

  • (Object)

    the current value of key_file



43
44
45
# File 'lib/vangrail/providers/gateway.rb', line 43

def key_file
  @key_file
end

#modelsObject

Returns the value of attribute models

Returns:

  • (Object)

    the current value of models



43
44
45
# File 'lib/vangrail/providers/gateway.rb', line 43

def models
  @models
end

#nameObject

Returns the value of attribute name

Returns:

  • (Object)

    the current value of name



43
44
45
# File 'lib/vangrail/providers/gateway.rb', line 43

def name
  @name
end

#pass_entryObject

Returns the value of attribute pass_entry

Returns:

  • (Object)

    the current value of pass_entry



43
44
45
# File 'lib/vangrail/providers/gateway.rb', line 43

def pass_entry
  @pass_entry
end

#pass_envObject

Returns the value of attribute pass_env

Returns:

  • (Object)

    the current value of pass_env



43
44
45
# File 'lib/vangrail/providers/gateway.rb', line 43

def pass_env
  @pass_env
end